@@ -1,5 +1,10 @@
-generateKPs = function(numNeeded, baserate, kappaMin, kappaMax, precisionMin, precisionMax, distributionType = 'FLAT', distributionLength = 100000){
-
+generateKPs = function(
+  numNeeded, baserate,
+  kappaMin, kappaMax,
+  precisionMin, precisionMax,
+  distributionType = 'FLAT',
+  distributionLength = 100000
+) {
   kappaDistribution = seq(kappaMin, kappaMax, length = distributionLength)
 
   if (distributionType == 'FLAT') {
@@ -8,7 +13,7 @@ generateKPs = function(numNeeded, baserate, kappaMin, kappaMax, precisionMin, pr
   }
   else if (distributionType == 'BELL') {
     #probability for a bell curve
-    kappaProbability = stats::dnorm(kappaDistribution, mean = 0.65, sd = 0.1)
+    kappaProbability = stats::dnorm(kappaDistribution, mean = 0.9, sd = 0.1)
   }
 
   precisionDistribution = seq(precisionMin, precisionMax, length = 10000)
@@ -16,7 +21,7 @@ generateKPs = function(numNeeded, baserate, kappaMin, kappaMax, precisionMin, pr
 
   KPs = tryCatch({
     KPs = list()
-    for(i in 1:numNeeded){
+    for (i in 1:numNeeded) {
       KPs[[length(KPs) + 1]] = genPKcombo(kappaDistribution, kappaProbability, precisionDistribution, precisionProbability, baserate)
     }
     KPs
